==> parodia_admin-1.0.2.tar.gz: lib/core/repository/tag.repository.dart <==
// POST
// /api/v1/dashboard/tags/slugify

// GET
// /api/v1/dashboard/tags/{id}

// PUT
// /api/v1/dashboard/tags/{id}

// DELETE
// /api/v1/dashboard/tags/{id}

// GET
// /api/v1/dashboard/tags

// POST
// /api/v1/dashboard/tags

// POST
// /api/v1/dashboard/tags/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/tag.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class TagRepository {
  ParodiaHTTP? _http;

  TagRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/tags/slugify',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO<TagDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/tags',
      param: id,
    );

    return ResponseItemDTO<TagDTO>(
      response: response,
      fromJson: TagDTO.fromJson,
    );
  }

  Future<ResponseListDTO<TagDTO>> getAll({
    StoreQuery? query,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/tags',
      query: query,
    );

    return ResponseListDTO<TagDTO>(
      response: response,
      fromJson: TagDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({TagBody? tag}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/tags',
      data: tag,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, TagBody? tag}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/tags',
      param: id,
      data: tag,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/tags',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/tags/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/tag.repository.dart <==
// POST
// /api/v1/dashboard/dashboard/tags/slugify

// GET
// /api/v1/dashboard/dashboard/tags/{id}

// PUT
// /api/v1/dashboard/dashboard/tags/{id}

// DELETE
// /api/v1/dashboard/dashboard/tags/{id}

// GET
// /api/v1/dashboard/dashboard/tags

// POST
// /api/v1/dashboard/dashboard/tags

// POST
// /api/v1/dashboard/dashboard/tags/{id}/recover

import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/dto/tag.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class TagRepository {
  ParodiaHTTP? _http;

  TagRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/tags/slugify',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO<TagDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/tags',
      param: id,
    );

    return ResponseItemDTO<TagDTO>(
      response: response,
      fromJson: TagDTO.fromJson,
    );
  }

  Future<ResponseListDTO<TagDTO>> getAll({
    StoreQuery? query,
  }) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/tags',
      query: query,
    );

    return ResponseListDTO<TagDTO>(
      response: response,
      fromJson: TagDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({TagBody? tag}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/tags',
      data: tag,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, TagBody? tag}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/tags',
      param: id,
      data: tag,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/tags',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/tags/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
